@@ -29,6 +29,7 @@ public class NokogiriService implements BasicLibraryService
     return true;
   }
 
+  @SuppressWarnings("unchecked")
   public static Map<String, RubyClass>
   getNokogiriClassCache(Ruby ruby)
   {
@@ -39,7 +40,6 @@ public class NokogiriService implements BasicLibraryService
   populateNokogiriClassCahce(Ruby ruby)
   {
     Map<String, RubyClass> nokogiriClassCache = new HashMap<String, RubyClass>();
-    nokogiriClassCache.put("Nokogiri::EncodingHandler", (RubyClass)ruby.getClassFromPath("Nokogiri::EncodingHandler"));
     nokogiriClassCache.put("Nokogiri::HTML4::Document", (RubyClass)ruby.getClassFromPath("Nokogiri::HTML4::Document"));
     nokogiriClassCache.put("Nokogiri::HTML4::ElementDescription",
                            (RubyClass)ruby.getClassFromPath("Nokogiri::HTML4::ElementDescription"));
@@ -85,8 +85,6 @@ public class NokogiriService implements BasicLibraryService
     RubyModule htmlSaxModule = htmlModule.defineModuleUnder("SAX");
     RubyModule xsltModule = nokogiri.defineModuleUnder("XSLT");
 
-    createJavaLibraryVersionConstants(ruby, nokogiri);
-    createNokogiriModule(ruby, nokogiri);
     createSyntaxErrors(ruby, nokogiri, xmlModule);
     RubyClass xmlNode = createXmlModule(ruby, xmlModule);
     createHtmlModule(ruby, htmlModule);
@@ -96,20 +94,6 @@ public class NokogiriService implements BasicLibraryService
     nokogiri.setInternalVariable("cache", populateNokogiriClassCahce(ruby));
   }
 
-  private void
-  createJavaLibraryVersionConstants(Ruby ruby, RubyModule nokogiri)
-  {
-    nokogiri.defineConstant("XERCES_VERSION", ruby.newString(org.apache.xerces.impl.Version.getVersion()));
-    nokogiri.defineConstant("NEKO_VERSION", ruby.newString(org.cyberneko.html.Version.getVersion()));
-  }
-
-  private void
-  createNokogiriModule(Ruby ruby, RubyModule nokogiri)
-  {
-    RubyClass encHandler = nokogiri.defineClassUnder("EncodingHandler", ruby.getObject(), ENCODING_HANDLER_ALLOCATOR);
-    encHandler.defineAnnotatedMethods(EncodingHandler.class);
-  }
-
   private void
   createSyntaxErrors(Ruby ruby, RubyModule nokogiri, RubyModule xmlModule)
   {
@@ -246,13 +230,6 @@ public class NokogiriService implements BasicLibraryService
     xsltModule.defineAnnotatedMethod(XsltStylesheet.class, "register");
   }
 
-  private static ObjectAllocator ENCODING_HANDLER_ALLOCATOR = new ObjectAllocator()
-  {
-    public IRubyObject allocate(Ruby runtime, RubyClass klazz) {
-      return new EncodingHandler(runtime, klazz, "");
-    }
-  };
-
   public static final ObjectAllocator HTML_DOCUMENT_ALLOCATOR = new ObjectAllocator()
   {
     private Html4Document htmlDocument = null;
