@@ -12,7 +12,7 @@ import java.util.*;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
-import org.cyberneko.html.HTMLElements;
+import net.sourceforge.htmlunit.cyberneko.HTMLElements;
 import org.w3c.dom.Attr;
 import org.w3c.dom.CDATASection;
 import org.w3c.dom.Comment;
@@ -81,6 +81,8 @@ public class SaveContextVisitor
   public static final int SUBSETS = 8;
   public static final int EXCLUSIVE = 16;
 
+  private static final HTMLElements htmlElements_ = new HTMLElements();
+
   public
   SaveContextVisitor(int options, CharSequence indent, String encoding, boolean htmlDoc, boolean fragment,
                      int canonicalOpts)
@@ -296,30 +298,30 @@ public class SaveContextVisitor
     for (int i = 0; i < str.length(); i++) {
       char c;
       switch (c = str.charAt(i)) {
-      case '\n':
-        buffer.append("&#10;");
-        break;
-      case '\r':
-        buffer.append("&#13;");
-        break;
-      case '\t':
-        buffer.append("&#9;");
-        break;
-      case '"':
-        if (htmlDoc) { buffer.append("%22"); }
-        else { buffer.append("&quot;"); }
-        break;
-      case '<':
-        buffer.append("&lt;");
-        break;
-      case '>':
-        buffer.append("&gt;");
-        break;
-      case '&':
-        buffer.append("&amp;");
-        break;
-      default:
-        buffer.append(c);
+        case '\n':
+          buffer.append("&#10;");
+          break;
+        case '\r':
+          buffer.append("&#13;");
+          break;
+        case '\t':
+          buffer.append("&#9;");
+          break;
+        case '"':
+          if (htmlDoc) { buffer.append("%22"); }
+          else { buffer.append("&quot;"); }
+          break;
+        case '<':
+          buffer.append("&lt;");
+          break;
+        case '>':
+          buffer.append("&gt;");
+          break;
+        case '&':
+          buffer.append("&amp;");
+          break;
+        default:
+          buffer.append(c);
       }
     }
 
@@ -498,7 +500,7 @@ public class SaveContextVisitor
   private boolean
   isEmpty(String name)
   {
-    HTMLElements.Element element = HTMLElements.getElement(name);
+    HTMLElements.Element element = htmlElements_.getElement(name);
     return element.isEmpty();
   }
 
@@ -673,6 +675,8 @@ public class SaveContextVisitor
       if (!isEmpty(name) && noEmpty) {
         buffer.append("</").append(name).append('>');
       }
+    } else if (asXhtml && !isEmpty(name)) {
+      buffer.append("</").append(name).append('>');
     }
     if (needBreakInClosing(element)) {
       if (!containsText(element)) { indentation.pop(); }
