@@ -3,10 +3,10 @@
 require "helper"
 
 module Nokogiri
-  module HTML
+  module HTML4
     class TestDocument < Nokogiri::TestCase
-      describe Nokogiri::HTML::Document do
-        let(:html) { Nokogiri::HTML.parse(File.read(HTML_FILE)) }
+      describe Nokogiri::HTML4::Document do
+        let(:html) { Nokogiri::HTML4.parse(File.read(HTML_FILE)) }
 
         def test_nil_css
           # Behavior is undefined but shouldn't break
@@ -15,7 +15,7 @@ module Nokogiri
         end
 
         def test_does_not_fail_with_illformatted_html
-          doc = Nokogiri::HTML((+'"</html>";').force_encoding(Encoding::BINARY))
+          doc = Nokogiri::HTML4((+'"</html>";').force_encoding(Encoding::BINARY))
           refute_nil(doc)
         end
 
@@ -34,7 +34,7 @@ module Nokogiri
 
         def test_document_takes_config_block
           options = nil
-          Nokogiri::HTML(File.read(HTML_FILE), HTML_FILE) do |cfg|
+          Nokogiri::HTML4(File.read(HTML_FILE), HTML_FILE) do |cfg|
             options = cfg
             options.nonet.nowarning.dtdattr
           end
@@ -45,7 +45,7 @@ module Nokogiri
 
         def test_parse_takes_config_block
           options = nil
-          Nokogiri::HTML.parse(File.read(HTML_FILE), HTML_FILE) do |cfg|
+          Nokogiri::HTML4.parse(File.read(HTML_FILE), HTML_FILE) do |cfg|
             options = cfg
             options.nonet.nowarning.dtdattr
           end
@@ -54,71 +54,39 @@ module Nokogiri
           assert_predicate(options, :dtdattr?)
         end
 
-        def test_subclass
-          klass = Class.new(Nokogiri::HTML::Document)
-          doc = klass.new
-          assert_instance_of(klass, doc)
-        end
-
-        def test_subclass_initialize
-          klass = Class.new(Nokogiri::HTML::Document) do
-            attr_accessor :initialized_with
-
-            def initialize(*args)
-              super
-              @initialized_with = args
-            end
-          end
-          doc = klass.new("uri", "external_id", 1)
-          assert_equal(["uri", "external_id", 1], doc.initialized_with)
-        end
-
-        def test_subclass_dup
-          klass = Class.new(Nokogiri::HTML::Document)
-          doc = klass.new.dup
-          assert_instance_of(klass, doc)
-        end
-
-        def test_subclass_parse
-          klass = Class.new(Nokogiri::HTML::Document)
-          doc = klass.parse(File.read(HTML_FILE))
-          assert_equal(html.to_s, doc.to_s)
-          assert_instance_of(klass, doc)
-        end
-
         def test_document_parse_method
-          html = Nokogiri::HTML::Document.parse(File.read(HTML_FILE))
+          html = Nokogiri::HTML4::Document.parse(File.read(HTML_FILE))
           assert_equal(html.to_s, html.to_s)
         end
 
         def test_document_parse_method_with_url
-          doc = Nokogiri::HTML("<html></html>", "http://foobar.example.com/", "UTF-8")
+          doc = Nokogiri::HTML4("<html></html>", "http://foobar.example.com/", "UTF-8")
           refute_empty(doc.to_s, "Document should not be empty")
           assert_equal("http://foobar.example.com/", doc.url)
         end
 
         ###
-        # Nokogiri::HTML returns an empty Document when given a blank string GH#11
+        # Nokogiri::HTML4 returns an empty Document when given a blank string GH#11
         def test_empty_string_returns_empty_doc
-          doc = Nokogiri::HTML("")
-          assert_instance_of(Nokogiri::HTML::Document, doc)
+          doc = Nokogiri::HTML4("")
+          assert_instance_of(Nokogiri::HTML4::Document, doc)
           assert_nil(doc.root)
         end
 
         def test_to_xhtml_with_indent
           skip if Nokogiri.uses_libxml?("~> 2.6.0")
-          doc = Nokogiri::HTML("<html><body><a>foo</a></body></html>")
-          doc = Nokogiri::HTML(doc.to_xhtml(indent: 2))
+          doc = Nokogiri::HTML4("<html><body><a>foo</a></body></html>")
+          doc = Nokogiri::HTML4(doc.to_xhtml(indent: 2))
           assert_indent(2, doc)
         end
 
         def test_write_to_xhtml_with_indent
           skip if Nokogiri.uses_libxml?("~> 2.6.0")
           io = StringIO.new
-          doc = Nokogiri::HTML("<html><body><a>foo</a></body></html>")
+          doc = Nokogiri::HTML4("<html><body><a>foo</a></body></html>")
           doc.write_xhtml_to(io, indent: 5)
           io.rewind
-          doc = Nokogiri::HTML(io.read)
+          doc = Nokogiri::HTML4(io.read)
           assert_indent(5, doc)
         end
 
@@ -139,7 +107,7 @@ module Nokogiri
         end
 
         def test_meta_encoding_is_strict_about_http_equiv
-          doc = Nokogiri::HTML(<<~EOHTML)
+          doc = Nokogiri::HTML4(<<~HTML)
             <html>
               <head>
                 <meta http-equiv="X-Content-Type" content="text/html; charset=Shift_JIS">
@@ -148,12 +116,12 @@ module Nokogiri
                 foo
               </body>
             </html>
-          EOHTML
+          HTML
           assert_nil(doc.meta_encoding)
         end
 
         def test_meta_encoding_handles_malformed_content_charset
-          doc = Nokogiri::HTML(<<~EOHTML)
+          doc = Nokogiri::HTML4(<<~HTML)
             <html>
               <head>
                 <meta http-equiv="Content-type" content="text/html; utf-8" />
@@ -162,12 +130,12 @@ module Nokogiri
                 foo
               </body>
             </html>
-          EOHTML
+          HTML
           assert_nil(doc.meta_encoding)
         end
 
         def test_meta_encoding_checks_charset
-          doc = Nokogiri::HTML(<<~EOHTML)
+          doc = Nokogiri::HTML4(<<~HTML)
             <html>
               <head>
                 <meta charset="UTF-8">
@@ -176,7 +144,7 @@ module Nokogiri
                 foo
               </body>
             </html>
-          EOHTML
+          HTML
           assert_equal("UTF-8", doc.meta_encoding)
         end
 
@@ -187,12 +155,12 @@ module Nokogiri
 
         def test_title
           assert_equal("Tender Lovemaking  ", html.title)
-          doc = Nokogiri::HTML("<html><body>foo</body></html>")
+          doc = Nokogiri::HTML4("<html><body>foo</body></html>")
           assert_nil(doc.title)
         end
 
         def test_title=
-          doc = Nokogiri::HTML(<<~EOHTML)
+          doc = Nokogiri::HTML4(<<~HTML)
             <html>
               <head>
                 <title>old</title>
@@ -201,12 +169,12 @@ module Nokogiri
                 foo
               </body>
             </html>
-          EOHTML
+          HTML
           doc.title = "new"
           assert_equal(1, doc.css("title").size)
           assert_equal("new", doc.title)
 
-          doc = Nokogiri::HTML(<<~EOHTML)
+          doc = Nokogiri::HTML4(<<~HTML)
             <html>
               <head>
                 <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
@@ -215,7 +183,7 @@ module Nokogiri
                 foo
               </body>
             </html>
-          EOHTML
+          HTML
           doc.title = "new"
           assert_equal("new", doc.title)
           title = doc.at("/html/head/title")
@@ -223,13 +191,13 @@ module Nokogiri
           assert_equal("new", title.text)
           assert_equal(-1, doc.at("meta[@http-equiv]") <=> title)
 
-          doc = Nokogiri::HTML(<<~EOHTML)
+          doc = Nokogiri::HTML4(<<~HTML)
             <html>
               <body>
                 foo
               </body>
             </html>
-          EOHTML
+          HTML
           doc.title = "new"
           assert_equal("new", doc.title)
           # <head> may or may not be added
@@ -238,26 +206,26 @@ module Nokogiri
           assert_equal("new", title.text)
           assert_equal(-1, title <=> doc.at("body"))
 
-          doc = Nokogiri::HTML(<<~EOHTML)
+          doc = Nokogiri::HTML4(<<~HTML)
             <html>
               <meta charset="UTF-8">
               <body>
                 foo
               </body>
             </html>
-          EOHTML
+          HTML
           doc.title = "new"
           assert_equal("new", doc.title)
           assert_equal(-1, doc.at("meta[@charset]") <=> doc.at("title"))
           assert_equal(-1, doc.at("title") <=> doc.at("body"))
 
-          doc = Nokogiri::HTML("<!DOCTYPE html><p>hello")
+          doc = Nokogiri::HTML4("<!DOCTYPE html><p>hello")
           doc.title = "new"
           assert_equal("new", doc.title)
           assert_instance_of(Nokogiri::XML::DTD, doc.children.first)
           assert_equal(-1, doc.at("title") <=> doc.at("p"))
 
-          doc = Nokogiri::HTML("")
+          doc = Nokogiri::HTML4("")
           doc.title = "new"
           assert_equal("new", doc.title)
           assert_equal("new", doc.at("/html/head/title/text()").to_s)
@@ -265,7 +233,7 @@ module Nokogiri
 
         def test_meta_encoding_without_head
           encoding = "EUC-JP"
-          html = Nokogiri::HTML("<html><body>foo</body></html>", nil, encoding)
+          html = Nokogiri::HTML4("<html><body>foo</body></html>", nil, encoding)
 
           assert_nil(html.meta_encoding)
 
@@ -280,7 +248,7 @@ module Nokogiri
 
         def test_html5_meta_encoding_without_head
           encoding = "EUC-JP"
-          html = Nokogiri::HTML("<!DOCTYPE html><html><body>foo</body></html>", nil, encoding)
+          html = Nokogiri::HTML4("<!DOCTYPE html><html><body>foo</body></html>", nil, encoding)
 
           assert_nil(html.meta_encoding)
 
@@ -294,7 +262,7 @@ module Nokogiri
         end
 
         def test_meta_encoding_with_empty_content_type
-          html = Nokogiri::HTML(<<~EOHTML)
+          html = Nokogiri::HTML4(<<~HTML)
             <html>
               <head>
                 <meta http-equiv="Content-Type" content="">
@@ -303,10 +271,10 @@ module Nokogiri
                 foo
               </body>
             </html>
-          EOHTML
+          HTML
           assert_nil(html.meta_encoding)
 
-          html = Nokogiri::HTML(<<~EOHTML)
+          html = Nokogiri::HTML4(<<~HTML)
             <html>
               <head>
                 <meta http-equiv="Content-Type">
@@ -315,30 +283,30 @@ module Nokogiri
                 foo
               </body>
             </html>
-          EOHTML
+          HTML
           assert_nil(html.meta_encoding)
         end
 
         def test_root_node_parent_is_document
           parent = html.root.parent
           assert_equal(html, parent)
-          assert_instance_of(Nokogiri::HTML::Document, parent)
+          assert_instance_of(Nokogiri::HTML4::Document, parent)
         end
 
         def test_parse_handles_nil_gracefully
-          @doc = Nokogiri::HTML::Document.parse(nil)
-          assert_instance_of(Nokogiri::HTML::Document, @doc)
+          @doc = Nokogiri::HTML4::Document.parse(nil)
+          assert_instance_of(Nokogiri::HTML4::Document, @doc)
         end
 
         def test_parse_empty_document
-          doc = Nokogiri::HTML("\n")
+          doc = Nokogiri::HTML4("\n")
           assert_equal(0, doc.css("a").length)
           assert_equal(0, doc.xpath("//a").length)
           assert_equal(0, doc.search("//a").length)
         end
 
-        def test_HTML_function
-          html = Nokogiri::HTML(File.read(HTML_FILE))
+        def test_html_predicate
+          html = Nokogiri::HTML4(File.read(HTML_FILE))
           assert_predicate(html, :html?)
         end
 
@@ -354,7 +322,7 @@ module Nokogiri
             end
           end
 
-          doc = Nokogiri::HTML.parse(klass.new)
+          doc = Nokogiri::HTML4.parse(klass.new)
           assert_equal("foo", doc.at_css("div").content)
         end
 
@@ -364,8 +332,8 @@ module Nokogiri
           temp_html_file.close
           temp_html_file.open
           assert_equal(
-            Nokogiri::HTML.parse(File.read(HTML_FILE)).xpath("//div/a").length,
-            Nokogiri::HTML.parse(temp_html_file).xpath("//div/a").length
+            Nokogiri::HTML4.parse(File.read(HTML_FILE)).xpath("//div/a").length,
+            Nokogiri::HTML4.parse(temp_html_file).xpath("//div/a").length,
           )
         end
 
@@ -378,23 +346,23 @@ module Nokogiri
         def test_to_xhtml_self_closing_tags
           # https://github.com/sparklemotion/nokogiri/issues/2324
           html = "<html><body><br><table><colgroup><col>"
-          doc = Nokogiri::HTML::Document.parse(html)
+          doc = Nokogiri::HTML4::Document.parse(html)
           xhtml = doc.to_xhtml
           assert_match(%r(<br ?/>), xhtml)
           assert_match(%r(<col ?/>), xhtml)
         end
 
         def test_no_xml_header
-          html = Nokogiri::HTML(<<~EOHTML)
+          html = Nokogiri::HTML4(<<~HTML)
             <html>
             </html>
-          EOHTML
+          HTML
           refute_empty(html.to_html, "html length is too short")
           refute_match(/^<\?xml/, html.to_html)
         end
 
         def test_document_has_error
-          html = Nokogiri::HTML(<<~EOHTML)
+          html = Nokogiri::HTML4(<<~HTML)
             <html>
               <body>
                 <div awesome="asdf>
@@ -403,12 +371,12 @@ module Nokogiri
                 <p>outside div tag</p>
               </body>
             </html>
-          EOHTML
+          HTML
           refute_empty(html.errors)
         end
 
         def test_relative_css
-          html = Nokogiri::HTML(<<~EOHTML)
+          html = Nokogiri::HTML4(<<~HTML)
             <html>
               <body>
                 <div>
@@ -417,14 +385,14 @@ module Nokogiri
                 <p>outside div tag</p>
               </body>
             </html>
-          EOHTML
+          HTML
           set = html.search("div").search("p")
           assert_equal(1, set.length)
           assert_equal("inside div tag", set.first.inner_text)
         end
 
         def test_multi_css
-          html = Nokogiri::HTML(<<~EOHTML)
+          html = Nokogiri::HTML4(<<~HTML)
             <html>
               <body>
                 <div>
@@ -433,14 +401,14 @@ module Nokogiri
                 </div>
               </body>
             </html>
-          EOHTML
+          HTML
           set = html.css("p, a")
           assert_equal(2, set.length)
           assert_equal(["a tag", "p tag"].sort, set.map(&:content).sort)
         end
 
         def test_inner_text
-          html = Nokogiri::HTML(<<~EOHTML)
+          html = Nokogiri::HTML4(<<~HTML)
             <html>
               <body>
                 <div>
@@ -450,31 +418,31 @@ module Nokogiri
                 </div>
               </body>
             </html>
-          EOHTML
+          HTML
           node = html.xpath("//div").first
           assert_equal("Hello world!", node.inner_text.strip)
         end
 
         def test_doc_type
-          html = Nokogiri::HTML(<<~EOHTML)
+          html = Nokogiri::HTML4(<<~HTML)
             <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
             <html xmlns="http://www.w3.org/1999/xhtml">
               <body>
                 <p>Rainbow Dash</p>
               </body>
             </html>
-          EOHTML
+          HTML
           assert_equal("html", html.internal_subset.name)
           assert_equal("-//W3C//DTD XHTML 1.1//EN", html.internal_subset.external_id)
           assert_equal("http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd", html.internal_subset.system_id)
           assert_equal(
             "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.1//EN\" \"http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd\">",
-            html.to_s[0, 97]
+            html.to_s[0, 97],
           )
         end
 
         def test_content_size
-          html = Nokogiri::HTML("<div>\n</div>")
+          html = Nokogiri::HTML4("<div>\n</div>")
           assert_equal(1, html.content.size)
           assert_equal(1, html.content.split("").size)
           assert_equal("\n", html.content)
@@ -536,7 +504,7 @@ module Nokogiri
           assert(dup = html.dup)
           refute_equal(dup, html)
           assert_predicate(html, :html?)
-          assert_instance_of(Nokogiri::HTML::Document, dup)
+          assert_instance_of(Nokogiri::HTML4::Document, dup)
           assert_predicate(dup, :html?, "duplicate should be html")
           assert_equal(html.to_s, dup.to_s)
         end
@@ -557,7 +525,7 @@ module Nokogiri
         # issue 1060
         def test_node_ownership_after_dup
           html = "<html><head></head><body><div>replace me</div></body></html>"
-          doc = Nokogiri::HTML::Document.parse(html)
+          doc = Nokogiri::HTML4::Document.parse(html)
           dup = doc.dup
           assert_same(dup, dup.at_css("div").document)
 
@@ -566,7 +534,7 @@ module Nokogiri
         end
 
         def test_inner_html
-          html = Nokogiri::HTML(<<~EOHTML)
+          html = Nokogiri::HTML4(<<~HTML)
             <html>
               <body>
                 <div>
@@ -576,28 +544,28 @@ module Nokogiri
                 </div>
               </body>
             </html>
-          EOHTML
+          HTML
           node = html.xpath("//div").first
           assert_equal("<p>Helloworld!</p>", node.inner_html.gsub(/\s/, ""))
         end
 
         def test_round_trip
-          doc = Nokogiri::HTML(html.inner_html)
+          doc = Nokogiri::HTML4(html.inner_html)
           assert_equal(html.root.to_html, doc.root.to_html)
         end
 
         def test_fragment_contains_text_node
-          fragment = Nokogiri::HTML.fragment("fooo")
+          fragment = Nokogiri::HTML4.fragment("fooo")
           assert_equal(1, fragment.children.length)
           assert_equal("fooo", fragment.inner_text)
         end
 
         def test_fragment_includes_two_tags
-          assert_equal(2, Nokogiri::HTML.fragment("<br/><hr/>").children.length)
+          assert_equal(2, Nokogiri::HTML4.fragment("<br/><hr/>").children.length)
         end
 
         def test_relative_css_finder
-          doc = Nokogiri::HTML(<<~EOHTML)
+          doc = Nokogiri::HTML4(<<~HTML)
             <html>
               <body>
                 <div class="red">
@@ -612,7 +580,7 @@ module Nokogiri
                 </div>
               </body>
             </html>
-          EOHTML
+          HTML
           red_divs = doc.css("div.red")
           assert_equal(1, red_divs.length)
           p_tags = red_divs.first.css("p")
@@ -621,7 +589,7 @@ module Nokogiri
         end
 
         def test_find_classes
-          doc = Nokogiri::HTML(<<~EOHTML)
+          doc = Nokogiri::HTML4(<<~HTML)
             <html>
               <body>
                 <p class="red">RED</p>
@@ -630,7 +598,7 @@ module Nokogiri
                 <p class="green notred">GREEN</p>
               </body>
             </html>
-          EOHTML
+          HTML
           list = doc.css(".red")
           assert_equal(2, list.length)
           assert_equal(["RED", "RED"], list.map(&:text))
@@ -639,7 +607,7 @@ module Nokogiri
         def test_parse_can_take_io
           html = nil
           File.open(HTML_FILE, "rb") do |f|
-            html = Nokogiri::HTML(f)
+            html = Nokogiri::HTML4(f)
           end
           assert_predicate(html, :html?)
           assert_equal(HTML_FILE, html.url)
@@ -651,7 +619,7 @@ module Nokogiri
             "/i/should/be/the/document/url"
           end
 
-          doc = Nokogiri::HTML.parse(html)
+          doc = Nokogiri::HTML4.parse(html)
 
           assert_equal("/i/should/be/the/document/url", doc.url)
         end
@@ -660,7 +628,7 @@ module Nokogiri
         def test_parse_can_take_pathnames
           assert(File.size(HTML_FILE) > 4096) # file must be big enough to trip the read callback more than once
 
-          doc = Nokogiri::HTML.parse(Pathname.new(HTML_FILE))
+          doc = Nokogiri::HTML4.parse(Pathname.new(HTML_FILE))
 
           # an arbitrary assertion on the structure of the document
           assert_equal(166, doc.css("a").length)
@@ -679,13 +647,13 @@ module Nokogiri
 
         def test_empty_document
           # empty document should return "" #699
-          assert_equal("", Nokogiri::HTML.parse(nil).text)
-          assert_equal("", Nokogiri::HTML.parse("").text)
+          assert_equal("", Nokogiri::HTML4.parse(nil).text)
+          assert_equal("", Nokogiri::HTML4.parse("").text)
         end
 
         def test_capturing_nonparse_errors_during_document_clone
           # see https://github.com/sparklemotion/nokogiri/issues/1196 for background
-          original = Nokogiri::HTML.parse("<div id='unique'></div><div id='unique'></div>")
+          original = Nokogiri::HTML4.parse("<div id='unique'></div><div id='unique'></div>")
           original_errors = original.errors.dup
 
           copy = original.dup
@@ -694,8 +662,8 @@ module Nokogiri
 
         def test_capturing_nonparse_errors_during_node_copy_between_docs
           # Errors should be emitted while parsing only, and should not change when moving nodes.
-          doc1 = Nokogiri::HTML("<html><body><diva id='unique'>one</diva></body></html>")
-          doc2 = Nokogiri::HTML("<html><body><dive id='unique'>two</dive></body></html>")
+          doc1 = Nokogiri::HTML4("<html><body><diva id='unique'>one</diva></body></html>")
+          doc2 = Nokogiri::HTML4("<html><body><dive id='unique'>two</dive></body></html>")
           node1 = doc1.at_css("#unique")
           node2 = doc2.at_css("#unique")
           original_errors1 = doc1.errors.dup
@@ -721,7 +689,7 @@ module Nokogiri
           # having `ID unique-issue-1262 already defined` emitted to
           # stderr when running the test suite.
           #
-          doc = Nokogiri::HTML::Document.new
+          doc = Nokogiri::HTML4::Document.new
           Nokogiri::XML::Element.new("div", doc).set_attribute("id", "unique-issue-1262")
           Nokogiri::XML::Element.new("div", doc).set_attribute("id", "unique-issue-1262")
           assert_equal(0, doc.errors.length)
@@ -734,41 +702,41 @@ module Nokogiri
           # don't otherwise have any test coverage for removing DTDs.
           #
           100.times do |_i|
-            Nokogiri::HTML::Document.new.internal_subset.remove
+            Nokogiri::HTML4::Document.new.internal_subset.remove
           end
         end
 
         it "skips encoding for script tags" do
-          html = Nokogiri::HTML(<<~EOHTML)
+          html = Nokogiri::HTML4(<<~HTML)
             <html>
               <head>
                 <script>var isGreater = 4 > 5;</script>
               </head>
               <body></body>
             </html>
-          EOHTML
+          HTML
           node = html.xpath("//script").first
           assert_equal("var isGreater = 4 > 5;", node.inner_html)
         end
 
         it "skips encoding for style tags" do
-          html = Nokogiri::HTML(<<~EOHTML)
+          html = Nokogiri::HTML4(<<~HTML)
             <html>
               <head>
                 <style>tr > div { display:block; }</style>
               </head>
               <body></body>
             </html>
-          EOHTML
+          HTML
           node = html.xpath("//style").first
           assert_equal("tr > div { display:block; }", node.inner_html)
         end
 
         it "does not fail when converting to_html using explicit encoding" do
-          html_fragment = <<~EOHTML
+          html_fragment = <<~HTML
             <img width="16" height="16" src="images/icon.gif" border="0" alt="Inactive hide details for &quot;User&quot; ---19/05/2015 12:55:29---Provvediamo subito nell&#8217;integrare">
-          EOHTML
-          doc = Nokogiri::HTML(html_fragment, nil, "ISO-8859-1")
+          HTML
+          doc = Nokogiri::HTML4(html_fragment, nil, "ISO-8859-1")
           html = doc.to_html
           assert html.index("src=\"images/icon.gif\"")
           assert_equal "ISO-8859-1", html.encoding.name
@@ -831,7 +799,7 @@ module Nokogiri
 
               it "raises exception on parse error" do
                 exception = assert_raises(Nokogiri::SyntaxError) do
-                  Nokogiri::HTML.parse(input, nil, nil, parse_options)
+                  Nokogiri::HTML4.parse(input, nil, nil, parse_options)
                 end
                 assert_match(/Parser without recover option encountered error or warning/, exception.to_s)
               end
@@ -839,7 +807,7 @@ module Nokogiri
 
             describe "default options" do
               it "does not raise exception on parse error" do
-                doc = Nokogiri::HTML.parse(input)
+                doc = Nokogiri::HTML4.parse(input)
                 assert_operator(doc.errors.length, :>, 0)
               end
             end
@@ -853,7 +821,7 @@ module Nokogiri
 
               it "raises exception on parse error" do
                 exception = assert_raises(Nokogiri::SyntaxError) do
-                  Nokogiri::HTML.parse(input, nil, "UTF-8", parse_options)
+                  Nokogiri::HTML4.parse(input, nil, "UTF-8", parse_options)
                 end
                 assert_match(/Parser without recover option encountered error or warning/, exception.to_s)
               end
@@ -861,7 +829,7 @@ module Nokogiri
 
             describe "default options" do
               it "does not raise exception on parse error" do
-                doc = Nokogiri::HTML.parse(input, nil, "UTF-8")
+                doc = Nokogiri::HTML4.parse(input, nil, "UTF-8")
                 assert_operator(doc.errors.length, :>, 0)
               end
             end
@@ -870,7 +838,7 @@ module Nokogiri
 
         describe "subclassing" do
           let(:klass) do
-            Class.new(Nokogiri::HTML::Document) do
+            Class.new(Nokogiri::HTML4::Document) do
               attr_accessor :initialized_with, :initialized_count
 
               def initialize(*args)
@@ -897,7 +865,7 @@ module Nokogiri
               doc = klass.new("http://www.w3.org/TR/REC-html40/loose.dtd", "-//W3C//DTD HTML 4.0 Transitional//EN")
               assert_equal(
                 ["http://www.w3.org/TR/REC-html40/loose.dtd", "-//W3C//DTD HTML 4.0 Transitional//EN"],
-                doc.initialized_with
+                doc.initialized_with,
               )
             end
           end
