@@ -89,14 +89,6 @@ class TestMemoryLeak < Nokogiri::TestCase
       puts "\ndike is not installed, skipping memory leak test"
     end
 
-    def test_node_set_namespace_mem_leak
-      xml = Nokogiri::XML("<foo></foo>")
-      ctx = Nokogiri::XML::XPathContext.new(xml)
-      loop do
-        ctx.evaluate("//namespace::*")
-      end
-    end
-
     def test_leak_on_node_replace
       loop do
         doc = Nokogiri.XML("<root><foo /></root>")
@@ -114,8 +106,8 @@ class TestMemoryLeak < Nokogiri::TestCase
         Nokogiri::XML::SAX::ParserContext.new(io)
         io.rewind
 
-        Nokogiri::HTML::SAX::ParserContext.new(@str)
-        Nokogiri::HTML::SAX::ParserContext.new(io)
+        Nokogiri::HTML4::SAX::ParserContext.new(@str)
+        Nokogiri::HTML4::SAX::ParserContext.new(io)
         io.rewind
       end
     end
@@ -136,7 +128,7 @@ class TestMemoryLeak < Nokogiri::TestCase
 
       loop do
         catch(:foo) do
-          Nokogiri::HTML::SAX::Parser.new(doc).parse(@str)
+          Nokogiri::HTML4::SAX::Parser.new(doc).parse(@str)
         end
       end
     end
@@ -161,14 +153,14 @@ class TestMemoryLeak < Nokogiri::TestCase
       end
     end
 
-    def test_leaking_namespace_node_strings
+    def test_builder_namespace_node_strings_no_prefix
       # see https://github.com/sparklemotion/nokogiri/issues/1810 for memory leak report
       ns = { "xmlns" => "http://schemas.xmlsoap.org/soap/envelope/" }
       20.times do
         10_000.times do
           Nokogiri::XML::Builder.new do |xml|
-            xml.send("Envelope", ns) do
-              xml.send("Foobar", ns)
+            xml.send(:Envelope, ns) do
+              xml.send(:Foobar, ns)
             end
           end
         end
@@ -176,14 +168,14 @@ class TestMemoryLeak < Nokogiri::TestCase
       end
     end
 
-    def test_leaking_namespace_node_strings_with_prefix
+    def test_builder_namespace_node_strings_with_prefix
       # see https://github.com/sparklemotion/nokogiri/issues/1810 for memory leak report
       ns = { "xmlns:foo" => "http://schemas.xmlsoap.org/soap/envelope/" }
       20.times do
         10_000.times do
           Nokogiri::XML::Builder.new do |xml|
-            xml.send("Envelope", ns) do
-              xml.send("Foobar", ns)
+            xml.send(:Envelope, ns) do
+              xml.send(:Foobar, ns)
             end
           end
         end
@@ -232,10 +224,31 @@ class TestMemoryLeak < Nokogiri::TestCase
       end
     end
 
+    def test_xpath_namespaces
+      xml = <<~XML
+        <root xmlns:a="http://a.flavorjon.es/" xmlns:b="http://b.flavorjon.es/">
+          <a:foo>hello from a</a:foo>
+          <b:foo>hello from b</b:foo>
+          <container xmlns:c="http://c.flavorjon.es/">
+            <c:foo c:attr='attr-value'>hello from c</c:foo>
+          </container>
+        </root>
+      XML
+      doc = Nokogiri::XML::Document.parse(xml)
+      ctx = Nokogiri::XML::XPathContext.new(doc)
+
+      20.times do
+        10_000.times do
+          ctx.evaluate("//namespace::*")
+        end
+        puts MemInfo.rss
+      end
+    end
+
     def test_leaking_dtd_nodes_after_internal_subset_removal
       # see https://github.com/sparklemotion/nokogiri/issues/1784
       100_000.times do |i|
-        doc = Nokogiri::HTML::Document.new
+        doc = Nokogiri::HTML4::Document.new
         doc.internal_subset.remove
         puts MemInfo.rss if i % 1000 == 0
       end
