@@ -151,7 +151,7 @@ module Nokogiri
         end
 
         def test_parse_with_unparented_html_text_context_node
-          doc = HTML::Document.new
+          doc = Nokogiri::HTML4::Document.new
           elem = XML::Text.new("div", doc)
           x = elem.parse("<div/>") # should not raise an exception
           assert_equal("div", x.first.name)
@@ -165,7 +165,7 @@ module Nokogiri
         end
 
         def test_parse_with_unparented_html_fragment_text_context_node
-          doc = HTML::DocumentFragment.parse("<div><span>foo</span></div>")
+          doc = Nokogiri::HTML4::DocumentFragment.parse("<div><span>foo</span></div>")
           elem = doc.at_css("span")
           x = elem.parse("<span/>") # should not raise an exception
           assert_equal("span", x.first.name)
@@ -196,8 +196,8 @@ module Nokogiri
 
         def test_dup_to_another_document
           skip_unless_libxml2("Node.dup with new_parent arg is only implemented on CRuby")
-          doc1 = HTML::Document.parse("<root><div><p>hello</p></div></root>")
-          doc2 = HTML::Document.parse("<div></div>")
+          doc1 = Nokogiri::HTML4::Document.parse("<root><div><p>hello</p></div></root>")
+          doc2 = Nokogiri::HTML4::Document.parse("<div></div>")
 
           div = doc1.at_css("div")
           duplicate_div = div.dup(1, doc2)
@@ -679,6 +679,14 @@ module Nokogiri
           end
         end
 
+        def test_write_to_file_without_encoding
+          Tempfile.create do |io|
+            xml.write_to(io)
+            io.rewind
+            assert_equal(xml.to_xml, io.read)
+          end
+        end
+
         def test_serialize_with_block
           called = false
           conf = nil
@@ -1127,13 +1135,16 @@ module Nokogiri
           #  describe how we handle microsoft word's HTML formatting.
           #  this test is descriptive, not prescriptive.
           #
-          html = Nokogiri::HTML.parse(<<~XML)
+          html = Nokogiri::HTML4.parse(<<~XML)
             <div><o:p>foo</o:p></div>
           XML
           node = html.at("div").children.first
           refute_nil(node)
 
-          if Nokogiri.uses_libxml?(">= 2.9.12")
+          if Nokogiri.uses_libxml?(">= 2.10.4") || Nokogiri.jruby?
+            assert_empty(node.namespaces.keys)
+            assert_equal("<o:p>foo</o:p>", node.to_html)
+          elsif Nokogiri.uses_libxml?(">= 2.9.12")
             assert_empty(node.namespaces.keys)
             assert_equal("<p>foo</p>", node.to_html)
           elsif Nokogiri.uses_libxml?
@@ -1141,9 +1152,6 @@ module Nokogiri
             assert(node.namespaces.key?("xmlns:o"))
             assert_nil(node.namespaces["xmlns:o"])
             assert_equal("<p>foo</p>", node.to_html)
-          else # jruby
-            assert_empty(node.namespaces.keys)
-            assert_equal("<o:p>foo</o:p>", node.to_html)
           end
         end
 
@@ -1291,19 +1299,71 @@ module Nokogiri
           # side note: this was fixed in libxml-ruby 2.9.0 by https://github.com/xml4r/libxml-ruby/pull/119
           message = "<section><h2>BOOM!</h2></section>"
           10_000.times do
-            node = Nokogiri::HTML::DocumentFragment.parse(message).at_css("h2")
+            node = Nokogiri::HTML4::DocumentFragment.parse(message).at_css("h2")
             node.add_previous_sibling(Nokogiri::XML::Text.new("before", node.document))
             node.add_next_sibling(Nokogiri::XML::Text.new("after", node.document))
           end
         end
 
-        def test_wrap
-          xml = '<root><thing><div class="title">important thing</div></thing></root>'
-          doc = Nokogiri::XML(xml)
-          thing = doc.at_css("thing")
-          thing.wrap("<wrapper/>")
-          assert_equal("wrapper", thing.parent.name)
-          assert_equal("thing", doc.at_css("wrapper").children.first.name)
+        describe "#wrap" do
+          let(:xml) { "<root><thing><div>important thing</div></thing></root>" }
+          let(:doc) { Nokogiri::XML(xml) }
+
+          describe "string markup argument" do
+            it "parses and wraps" do
+              thing = doc.at_css("thing")
+              rval = thing.wrap("<wrapper/>")
+              wrapper = doc.at_css("wrapper")
+
+              assert_equal(rval, thing)
+              assert_equal(wrapper, thing.parent)
+              assert_equal("root", wrapper.parent.name)
+              assert_equal(1, wrapper.children.length)
+              assert_equal("thing", wrapper.children.first.name)
+            end
+
+            it "wraps unparented nodes" do
+              thing = doc.create_element("thing")
+              thing.wrap("<wrapper/>")
+
+              assert_equal("wrapper", thing.parent.name)
+              assert_nil(thing.parent.parent)
+            end
+          end
+
+          describe "Node argument" do
+            it "wraps using a dup of the node" do
+              thing = doc.at_css("thing")
+              wrapper_template = doc.create_element("wrapper")
+              rval = thing.wrap(wrapper_template)
+              wrapper = doc.at_css("wrapper")
+
+              assert_equal(rval, thing)
+              refute_equal(wrapper, wrapper_template)
+              assert_equal(wrapper, thing.parent)
+              assert_equal("root", wrapper.parent.name)
+              assert_equal(1, wrapper.children.length)
+              assert_equal("thing", wrapper.children.first.name)
+            end
+
+            it "wraps unparented nodes" do
+              thing = doc.create_element("thing")
+              wrapper_template = doc.create_element("wrapper")
+              thing.wrap(wrapper_template)
+
+              refute_equal(wrapper_template, thing.parent)
+              assert_equal("wrapper", thing.parent.name)
+              assert_nil(thing.parent.parent)
+            end
+          end
+
+          it "raises an ArgumentError on other types" do
+            thing = doc.at_css("thing")
+
+            assert_raises(ArgumentError) do
+              thing.wrap(1)
+            end
+          end
         end
 
         describe "#line" do
