@@ -684,34 +684,64 @@ module Nokogiri
 
       def test_broken_markup_attribute_hash
         xml = <<~XML
-          <root><foo bar="asdf" xmlns:quux="qwer">
+          <root><foo bar="asdf" xmlns:quux="qwer">#{"x" * 1024}
         XML
         reader = Nokogiri::XML::Reader(xml)
         reader.read # root
         reader.read # foo
 
         assert_equal("foo", reader.name)
+        assert_equal(0, reader.errors.length)
+
         if Nokogiri.jruby?
           assert_equal({ "bar" => "asdf" }, reader.attribute_hash)
+
+          reader.read # text (xxxxx)
+          reader.read # text (newline)
+
+          e = assert_raises(Nokogiri::XML::SyntaxError) do
+            reader.read
+          end
+          assert_includes(e.message, "XML document structures must start and end")
         else
-          assert_nil(reader.attribute_hash)
+          e = assert_raises(Nokogiri::XML::SyntaxError) do
+            reader.attribute_hash
+          end
+          assert_includes(e.message, "FATAL: Extra content at the end of the document")
         end
+
+        assert_equal(1, reader.errors.length)
       end
 
       def test_broken_markup_namespaces
         xml = <<~XML
-          <root><foo bar="asdf" xmlns:quux="qwer">
+          <root><foo bar="asdf" xmlns:quux="qwer">#{"x" * 1024}
         XML
         reader = Nokogiri::XML::Reader(xml)
         reader.read # root
         reader.read # foo
 
         assert_equal("foo", reader.name)
+        assert_equal(0, reader.errors.length)
+
         if Nokogiri.jruby?
           assert_equal({ "xmlns:quux" => "qwer" }, reader.namespaces)
+
+          reader.read # text (xxxxx)
+          reader.read # text (newline)
+
+          e = assert_raises(Nokogiri::XML::SyntaxError) do
+            reader.read
+          end
+          assert_includes(e.message, "XML document structures must start and end")
         else
-          assert_nil(reader.namespaces)
+          e = assert_raises(Nokogiri::XML::SyntaxError) do
+            reader.namespaces
+          end
+          assert_includes(e.message, "FATAL: Extra content at the end of the document")
         end
+
+        assert_equal(1, reader.errors.length)
       end
     end
   end
