@@ -116,7 +116,7 @@ module Nokogiri
       def test_css_search_with_ambiguous_integer_or_string_attributes
         # https://github.com/sparklemotion/nokogiri/issues/711
         html = "<body><div><img width=200>"
-        doc = Nokogiri::HTML(html)
+        doc = Nokogiri::HTML4(html)
         refute_nil(doc.at_css("img[width='200']"))
         refute_nil(doc.at_css("img[width=200]"))
       end
@@ -156,6 +156,16 @@ module Nokogiri
         end
       end
 
+      def test_search_with_xpath_query_using_namespaced_custom_function
+        # Note that invocation with namespaces was not historically supported in CRuby.
+        # see https://github.com/sparklemotion/nokogiri/issues/2147 for more context.
+        set = @xml.xpath('//employee/address[nokogiri:my_filter(., "domestic", "Yes")]', @handler)
+        refute_empty(set)
+        set.each do |node|
+          assert_equal("Yes", node["domestic"])
+        end
+      end
+
       def test_pass_self_to_function
         set = if Nokogiri.uses_libxml?
           @xml.xpath('//employee/address[my_filter(., "domestic", "Yes")]', @handler)
@@ -315,7 +325,7 @@ module Nokogiri
       def test_code_that_invokes_OP_RESET_inside_libxml2
         doc = "<html><body id='foo'><foo>hi</foo></body></html>"
         xpath = 'id("foo")//foo'
-        nokogiri = Nokogiri::HTML.parse(doc)
+        nokogiri = Nokogiri::HTML4.parse(doc)
         assert(nokogiri.xpath(xpath))
       end
 
@@ -500,7 +510,7 @@ module Nokogiri
 
       describe "nokogiri-builtin:css-class xpath function" do
         before do
-          @doc = Nokogiri::HTML::Document.parse("<html></html>")
+          @doc = Nokogiri::HTML4::Document.parse("<html></html>")
         end
 
         it "accepts exactly two arguments" do
